"""Central module to define paths."""

from pathlib import Path

ROOT_DIR = Path.home() / ".cache/offline-docs/"

PYTHON_DIR = ROOT_DIR / "python"
